@@ -14,7 +14,7 @@ class DummyBackend(ThreadingActor, base.Backend):
     """
 
     def __init__(self, *args, **kwargs):
-        super(DummyBackend, self).__init__(*args, **kwargs)
+        super(DummyBackend, self).__init__()
 
         self.current_playlist = core.CurrentPlaylistController(backend=self)
 
