@@ -1,5 +1,6 @@
 from collections import namedtuple
 
+
 class ImmutableObject(object):
     """
     Superclass for immutable objects whose fields can only be modified via the
@@ -74,6 +75,19 @@ class ImmutableObject(object):
                 % key)
         return self.__class__(**data)
 
+    def serialize(self):
+        data = {}
+        for key in self.__dict__.keys():
+            public_key = key.lstrip('_')
+            value = self.__dict__[key]
+            if isinstance(value, (set, frozenset, list, tuple)):
+                value = [o.serialize() for o in value]
+            elif isinstance(value, ImmutableObject):
+                value = value.serialize()
+            if value:
+                data[public_key] = value
+        return data
+
 
 class Artist(ImmutableObject):
     """
@@ -144,8 +158,8 @@ class Track(ImmutableObject):
     :type album: :class:`Album`
     :param track_no: track number in album
     :type track_no: integer
-    :param date: track release date
-    :type date: :class:`datetime.date`
+    :param date: track release date (YYYY or YYYY-MM-DD)
+    :type date: string
     :param length: track length in milliseconds
     :type length: integer
     :param bitrate: bitrate in kbit/s
@@ -216,6 +230,8 @@ class Playlist(ImmutableObject):
         self.__dict__['tracks'] = tuple(kwargs.pop('tracks', []))
         super(Playlist, self).__init__(*args, **kwargs)
 
+    # TODO: def insert(self, pos, track): ... ?
+
     @property
     def length(self):
         """The number of tracks in the playlist. Read-only."""
