@@ -4,8 +4,7 @@ import mock
 
 from mopidy import OptionalDependencyError
 from mopidy.backends.dummy import DummyBackend
-from mopidy.backends.base.playback import PlaybackController
-from mopidy.mixers.dummy import DummyMixer
+from mopidy.core import PlaybackState
 from mopidy.models import Album, Artist, Track
 
 try:
@@ -15,23 +14,21 @@ except OptionalDependencyError:
 
 from tests import unittest
 
-PLAYING = PlaybackController.PLAYING
-PAUSED = PlaybackController.PAUSED
-STOPPED = PlaybackController.STOPPED
+PLAYING = PlaybackState.PLAYING
+PAUSED = PlaybackState.PAUSED
+STOPPED = PlaybackState.STOPPED
 
 
 @unittest.skipUnless(sys.platform.startswith('linux'), 'requires Linux')
 class PlayerInterfaceTest(unittest.TestCase):
     def setUp(self):
         objects.MprisObject._connect_to_dbus = mock.Mock()
-        self.mixer = DummyMixer.start().proxy()
         self.backend = DummyBackend.start().proxy()
         self.mpris = objects.MprisObject()
         self.mpris._backend = self.backend
 
     def tearDown(self):
         self.backend.stop()
-        self.mixer.stop()
 
     def test_get_playback_status_is_playing_when_playing(self):
         self.backend.playback.state = PLAYING
@@ -144,7 +141,7 @@ class PlayerInterfaceTest(unittest.TestCase):
 
     def test_get_metadata_has_trackid_even_when_no_current_track(self):
         result = self.mpris.Get(objects.PLAYER_IFACE, 'Metadata')
-        self.assert_('mpris:trackid' in result.keys())
+        self.assertIn('mpris:trackid', result.keys())
         self.assertEquals(result['mpris:trackid'], '')
 
     def test_get_metadata_has_trackid_based_on_cpid(self):
@@ -208,36 +205,40 @@ class PlayerInterfaceTest(unittest.TestCase):
         self.assertEquals(result['xesam:trackNumber'], 7)
 
     def test_get_volume_should_return_volume_between_zero_and_one(self):
-        self.mixer.volume = 0
+        self.backend.playback.volume = None
         result = self.mpris.Get(objects.PLAYER_IFACE, 'Volume')
         self.assertEquals(result, 0)
 
-        self.mixer.volume = 50
+        self.backend.playback.volume = 0
+        result = self.mpris.Get(objects.PLAYER_IFACE, 'Volume')
+        self.assertEquals(result, 0)
+
+        self.backend.playback.volume = 50
         result = self.mpris.Get(objects.PLAYER_IFACE, 'Volume')
         self.assertEquals(result, 0.5)
 
-        self.mixer.volume = 100
+        self.backend.playback.volume = 100
         result = self.mpris.Get(objects.PLAYER_IFACE, 'Volume')
         self.assertEquals(result, 1)
 
     def test_set_volume_is_ignored_if_can_control_is_false(self):
         self.mpris.get_CanControl = lambda *_: False
-        self.mixer.volume = 0
+        self.backend.playback.volume = 0
         self.mpris.Set(objects.PLAYER_IFACE, 'Volume', 1.0)
-        self.assertEquals(self.mixer.volume.get(), 0)
+        self.assertEquals(self.backend.playback.volume.get(), 0)
 
     def test_set_volume_to_one_should_set_mixer_volume_to_100(self):
         self.mpris.Set(objects.PLAYER_IFACE, 'Volume', 1.0)
-        self.assertEquals(self.mixer.volume.get(), 100)
+        self.assertEquals(self.backend.playback.volume.get(), 100)
 
     def test_set_volume_to_anything_above_one_should_set_mixer_volume_to_100(self):
         self.mpris.Set(objects.PLAYER_IFACE, 'Volume', 2.0)
-        self.assertEquals(self.mixer.volume.get(), 100)
+        self.assertEquals(self.backend.playback.volume.get(), 100)
 
     def test_set_volume_to_anything_not_a_number_does_not_change_volume(self):
-        self.mixer.volume = 10
+        self.backend.playback.volume = 10
         self.mpris.Set(objects.PLAYER_IFACE, 'Volume', None)
-        self.assertEquals(self.mixer.volume.get(), 10)
+        self.assertEquals(self.backend.playback.volume.get(), 10)
 
     def test_get_position_returns_time_position_in_microseconds(self):
         self.backend.current_playlist.append([Track(uri='a', length=40000)])
