@@ -43,7 +43,7 @@ class GenericCopyTets(unittest.TestCase):
         artist2 = Artist(name='bar')
         track = Track(artists=[artist1])
         copy = track.copy(artists=[artist2])
-        self.assert_(artist2 in copy.artists)
+        self.assertIn(artist2, copy.artists)
 
     def test_copying_track_with_invalid_key(self):
         test = lambda: Track().copy(invalid_key=True)
@@ -79,6 +79,11 @@ class ArtistTest(unittest.TestCase):
             "Artist(name='name', uri='uri')",
             repr(Artist(uri='uri', name='name')))
 
+    def test_serialize(self):
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name'},
+            Artist(uri='uri', name='name').serialize())
+
     def test_eq_name(self):
         artist1 = Artist(name=u'name')
         artist2 = Artist(name=u'name')
@@ -150,7 +155,7 @@ class AlbumTest(unittest.TestCase):
     def test_artists(self):
         artist = Artist()
         album = Album(artists=[artist])
-        self.assert_(artist in album.artists)
+        self.assertIn(artist, album.artists)
         self.assertRaises(AttributeError, setattr, album, 'artists', None)
 
     def test_num_tracks(self):
@@ -180,6 +185,17 @@ class AlbumTest(unittest.TestCase):
             "Album(artists=[Artist(name='foo')], name='name', uri='uri')",
             repr(Album(uri='uri', name='name', artists=[Artist(name='foo')])))
 
+    def test_serialize_without_artists(self):
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name'},
+            Album(uri='uri', name='name').serialize())
+
+    def test_serialize_with_artists(self):
+        artist = Artist(name='foo')
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name', 'artists': [artist.serialize()]},
+            Album(uri='uri', name='name', artists=[artist]).serialize())
+
     def test_eq_name(self):
         album1 = Album(name=u'name')
         album2 = Album(name=u'name')
@@ -322,7 +338,7 @@ class TrackTest(unittest.TestCase):
         self.assertRaises(AttributeError, setattr, track, 'track_no', None)
 
     def test_date(self):
-        date = datetime.date(1977, 1, 1)
+        date = '1977-01-01'
         track = Track(date=date)
         self.assertEqual(track.date, date)
         self.assertRaises(AttributeError, setattr, track, 'date', None)
@@ -360,6 +376,23 @@ class TrackTest(unittest.TestCase):
             "Track(artists=[Artist(name='foo')], name='name', uri='uri')",
             repr(Track(uri='uri', name='name', artists=[Artist(name='foo')])))
 
+    def test_serialize_without_artists(self):
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name'},
+            Track(uri='uri', name='name').serialize())
+
+    def test_serialize_with_artists(self):
+        artist = Artist(name='foo')
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name', 'artists': [artist.serialize()]},
+            Track(uri='uri', name='name', artists=[artist]).serialize())
+
+    def test_serialize_with_album(self):
+        album = Album(name='foo')
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name', 'album': album.serialize()},
+            Track(uri='uri', name='name', album=album).serialize())
+
     def test_eq_uri(self):
         track1 = Track(uri=u'uri1')
         track2 = Track(uri=u'uri1')
@@ -401,7 +434,7 @@ class TrackTest(unittest.TestCase):
         self.assertEqual(hash(track1), hash(track2))
 
     def test_eq_date(self):
-        date = datetime.date.today()
+        date = '1977-01-01'
         track1 = Track(date=date)
         track2 = Track(date=date)
         self.assertEqual(track1, track2)
@@ -426,7 +459,7 @@ class TrackTest(unittest.TestCase):
         self.assertEqual(hash(track1), hash(track2))
 
     def test_eq(self):
-        date = datetime.date.today()
+        date = '1977-01-01'
         artists = [Artist()]
         album = Album()
         track1 = Track(uri=u'uri', name=u'name', artists=artists, album=album,
@@ -475,8 +508,8 @@ class TrackTest(unittest.TestCase):
         self.assertNotEqual(hash(track1), hash(track2))
 
     def test_ne_date(self):
-        track1 = Track(date=datetime.date.today())
-        track2 = Track(date=datetime.date.today()-datetime.timedelta(days=1))
+        track1 = Track(date='1977-01-01')
+        track2 = Track(date='1977-01-02')
         self.assertNotEqual(track1, track2)
         self.assertNotEqual(hash(track1), hash(track2))
 
@@ -501,12 +534,12 @@ class TrackTest(unittest.TestCase):
     def test_ne(self):
         track1 = Track(uri=u'uri1', name=u'name1',
             artists=[Artist(name=u'name1')], album=Album(name=u'name1'),
-            track_no=1, date=datetime.date.today(), length=100, bitrate=100,
+            track_no=1, date='1977-01-01', length=100, bitrate=100,
             musicbrainz_id='id1')
         track2 = Track(uri=u'uri2', name=u'name2',
             artists=[Artist(name=u'name2')], album=Album(name=u'name2'),
-            track_no=2, date=datetime.date.today()-datetime.timedelta(days=1),
-            length=200, bitrate=200, musicbrainz_id='id2')
+            track_no=2, date='1977-01-02', length=200, bitrate=200,
+            musicbrainz_id='id2')
         self.assertNotEqual(track1, track2)
         self.assertNotEqual(hash(track1), hash(track2))
 
@@ -603,6 +636,17 @@ class PlaylistTest(unittest.TestCase):
             "uri='uri')",
             repr(Playlist(uri='uri', name='name', tracks=[Track(name='foo')])))
 
+    def test_serialize_without_tracks(self):
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name'},
+            Playlist(uri='uri', name='name').serialize())
+
+    def test_serialize_with_tracks(self):
+        track = Track(name='foo')
+        self.assertDictEqual(
+            {'uri': 'uri', 'name': 'name', 'tracks': [track.serialize()]},
+            Playlist(uri='uri', name='name', tracks=[track]).serialize())
+
     def test_eq_name(self):
         playlist1 = Playlist(name=u'name')
         playlist2 = Playlist(name=u'name')
